cgroups

package
v0.0.0-...-5dac054 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jun 11, 2024 License: MIT Imports: 1 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func ConfigureCgroup

func ConfigureCgroup(rootPath, cpuQuota string) error

ConfigureCGroup writes Cgroup creates a custom Cgroup, and the necessary files needed to limit resource usage, inside the /fs/sys/cgroup directory available at the specified rooth FS path

Types

This section is empty.

Jump to