Documentation
¶
Index ¶
Constants ¶
const (
DefaultRootfsPath = "/tmp/coso/rootfs"
)
Variables ¶
This section is empty.
Functions ¶
func MountProc ¶
MountProc executes a mount syscallmount, mounting the proc filesystem at mountpoint (default is /proc).
This is useful when creating a new PID namespace. MountProc should not be executed inside the default/global namespace since the /proc mount would otherwise mess up existing programs on the system.
func PivotRoot ¶
PivotRoot executes a pivot_root syscall, setting a new root filesystem for the calling process
A pivot_root syscall has some requirements:
- They must both be directories
- They must not be on the same filesystem as the current root
- putold must be underneath newroot
- No other filesystem may be mounted on putold
func VerifyRootfsExists ¶
func VerifyRootfsExists(rootfsPath string)
VerifyRootfsExists checks a valid root filesystem to use as lower layer has been provided
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.